python-dokuwiki
===============

Overview
--------
This module has for purpose to manager DokuWiki by using the XML-RPC API.
Details of the API are available at https://www.dokuwiki.org/devel:xmlrpc. The
module is compatible with both python 2 and 3.
